==> slurpit_sdk-0.9.40.tar.gz: slurpit_sdk-0.9.40/src/slurpit/apis/baseapi.py <==
import httpx
import pandas as pd
from io import BytesIO
import os

class BaseAPI:
    def __init__(self, api_key):
        """
        Initializes a new instance of the BaseAPI class with an `httpx` client.
        Args:
            api_key (str): The API key used for authorization, included in the headers of all requests.
        """
        self.client = httpx.AsyncClient()  # Creates an async client to persist certain parameters across requests
        self.client.headers.update({
            'Authorization': f'Bearer {api_key}',  # Bearer token for authorization
            'Content-Type': 'application/json'     # Sets default content type to JSON for all requests
        })

    async def get(self, url, **kwargs):
        """
        Sends an async GET request to the specified URL using httpx.
        Args:
            url (str): The URL to send the GET request to.
            **kwargs: Arbitrary keyword arguments that are forwarded to the `httpx.get` method.
        Returns:
            httpx.Response: The response object if the request was successful.
        Raises:
            httpx.HTTPStatusError: For responses with HTTP error statuses.
            httpx.RequestError: For network-related issues.
        """
        response = await self.client.get(url, **kwargs)  # Sends a GET request
        response.raise_for_status()  # Raises an exception for HTTP error codes
        return response

    async def post(self, url, data, **kwargs):
        """
        Sends an async POST request with JSON data to the specified URL using httpx.
        Args:
            url (str): The URL to send the POST request to.
            data (dict): The JSON data to send in the body of the POST request.
            **kwargs: Arbitrary keyword arguments that are forwarded to the `httpx.post` method.
        Returns:
            httpx.Response: The response object if the request was successful.
        """
        response = await self.client.post(url, json=data, **kwargs)
        response.raise_for_status()
        return response

    async def put(self, url, data, **kwargs):
        """
        Sends an async PUT request with JSON data to the specified URL using httpx.
        Args:
            url (str): The URL to send the PUT request to.
            data (dict): The JSON data to send in the body of the PUT request.
            **kwargs: Arbitrary keyword arguments that are forwarded to the `httpx.put` method.
        Returns:
            httpx.Response: The response object if the request was successful.
        """
        response = await self.client.put(url, json=data, **kwargs)
        response.raise_for_status()
        return response

    async def delete(self, url, **kwargs):
        """
        Sends an async DELETE request to the specified URL using httpx.
        Args:
            url (str): The URL to send the DELETE request to.
            **kwargs: Arbitrary keyword arguments that are forwarded to the `httpx.delete` method.
        Returns:
            httpx.Response: The response object if the request was successful.
        """
        response = await self.client.delete(url, **kwargs)
        response.raise_for_status()
        return response


    def json_to_csv_bytes(self, json_data):
        """
        Converts JSON data to CSV byte array.

        Args:
            json_data (list[dict]): A list of dictionaries representing JSON data.

        Returns:
            bytes: CSV formatted data as a byte array.
        """
        # Convert JSON to DataFrame
        df = pd.DataFrame(json_data)
        
        # Create a buffer
        buffer = BytesIO()
        
        # Convert DataFrame to CSV and save it to buffer
        df.to_csv(buffer, index=False)
        buffer.seek(0)  # Rewind the buffer to the beginning
        
        # Return bytes
        return buffer.getvalue()
    
    def save_csv_bytes(self, byte_data, filename):
        """
        Saves CSV byte array data to a CSV file.

        Args:
            byte_data (bytes): CSV data in byte array format.
            filename (str): The filename to save the CSV file as.
        """
        directory = os.path.dirname(filename)
        if not os.path.exists(directory):
            os.makedirs(directory)
            
        # Open file in binary write mode and write byte data
        with open(filename, 'wb') as file:
            file.write(byte_data)
        return True

==> slurpit_sdk-0.9.43.tar.gz: slurpit_sdk-0.9.43/src/slurpit/apis/baseapi.py <==
import httpx
import pandas as pd
from io import BytesIO
import os

class BaseAPI:
    def __init__(self, api_key):
        """
        Initializes a new instance of the BaseAPI class with an `httpx` client.
        Args:
            api_key (str): The API key used for authorization, included in the headers of all requests.
        """
        self.client = httpx.AsyncClient(timeout=30)  # Creates an async client to persist certain parameters across requests
        self.client.headers.update({
            'Authorization': f'Bearer {api_key}',  # Bearer token for authorization
            'Content-Type': 'application/json'     # Sets default content type to JSON for all requests
        })

    async def get(self, url, **kwargs):
        """
        Sends an async GET request to the specified URL using httpx.
        Args:
            url (str): The URL to send the GET request to.
            **kwargs: Arbitrary keyword arguments that are forwarded to the `httpx.get` method.
        Returns:
            httpx.Response: The response object if the request was successful.
        Raises:
            httpx.HTTPStatusError: For responses with HTTP error statuses.
            httpx.RequestError: For network-related issues.
        """
        response = await self.client.get(url, **kwargs)  # Sends a GET request
        response.raise_for_status()  # Raises an exception for HTTP error codes
        return response

    async def post(self, url, data, **kwargs):
        """
        Sends an async POST request with JSON data to the specified URL using httpx.
        Args:
            url (str): The URL to send the POST request to.
            data (dict): The JSON data to send in the body of the POST request.
            **kwargs: Arbitrary keyword arguments that are forwarded to the `httpx.post` method.
        Returns:
            httpx.Response: The response object if the request was successful.
        """
        response = await self.client.post(url, json=data, **kwargs)
        response.raise_for_status()
        return response

    async def put(self, url, data, **kwargs):
        """
        Sends an async PUT request with JSON data to the specified URL using httpx.
        Args:
            url (str): The URL to send the PUT request to.
            data (dict): The JSON data to send in the body of the PUT request.
            **kwargs: Arbitrary keyword arguments that are forwarded to the `httpx.put` method.
        Returns:
            httpx.Response: The response object if the request was successful.
        """
        response = await self.client.put(url, json=data, **kwargs)
        response.raise_for_status()
        return response

    async def delete(self, url, **kwargs):
        """
        Sends an async DELETE request to the specified URL using httpx.
        Args:
            url (str): The URL to send the DELETE request to.
            **kwargs: Arbitrary keyword arguments that are forwarded to the `httpx.delete` method.
        Returns:
            httpx.Response: The response object if the request was successful.
        """
        response = await self.client.delete(url, **kwargs)
        response.raise_for_status()
        return response


    def json_to_csv_bytes(self, json_data):
        """
        Converts JSON data to CSV byte array.

        Args:
            json_data (list[dict]): A list of dictionaries representing JSON data.

        Returns:
            bytes: CSV formatted data as a byte array.
        """
        # Convert JSON to DataFrame
        df = pd.DataFrame(json_data)
        
        # Create a buffer
        buffer = BytesIO()
        
        # Convert DataFrame to CSV and save it to buffer
        df.to_csv(buffer, index=False)
        buffer.seek(0)  # Rewind the buffer to the beginning
        
        # Return bytes
        return buffer.getvalue()
    
    def save_csv_bytes(self, byte_data, filename):
        """
        Saves CSV byte array data to a CSV file.

        Args:
            byte_data (bytes): CSV data in byte array format.
            filename (str): The filename to save the CSV file as.
        """
        directory = os.path.dirname(filename)
        if not os.path.exists(directory):
            os.makedirs(directory)
            
        # Open file in binary write mode and write byte data
        with open(filename, 'wb') as file:
            file.write(byte_data)
        return True

    async def _pager(self, url, payload=None, offset=0, limit=1000, method="GET"):
        params = {'limit': limit}
        if payload is None:
            payload = {}
        payload_copy = payload.copy()  # Prevent modifying original payload
        payload_copy.update(params)

        data = list()

        async def get_page(offset_value):
            payload_copy['offset'] = offset_value
            try:
                if method == "GET":
                    resp = await self.get(url, params=payload_copy)
                elif method == "POST":
                    resp = await self.post(url, payload_copy)
                else:
                    raise ValueError(f"Unsupported method: {method}")
                temp_data = resp.json()
                if "rows" in temp_data:
                    return temp_data.get("rows", [])
                else:
                    return temp_data
            except Exception as e:
                Exception(f"Error fetching page with offset {offset_value}: {str(e)}")



        # Fetch initial page
        new_page = await get_page(offset)
        data.extend(new_page)

        # Continue fetching until fewer results than limit are returned
        while limit == len(new_page):
            offset += limit
            new_page = await get_page(offset)
            data.extend(new_page)

        return data
